/*
    qtZenOscillo : Software for using DSO-2020 usb scope under Linux
    Copyright (C) 2015 Olivier Poitevin

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    Contact : code@zener.fr

*/

#include "mainwindow.h"
#include "ui_mainwindow.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    scopeRunning=false;
    ui->setupUi(this);

    // init all
    on_checkBoxCH1State_toggled(ui->checkBoxCH1State);
    on_checkBoxCH2State_toggled(ui->checkBoxCH2State);
    on_ComboSpeed_currentIndexChanged(ui->ComboSpeed->currentIndex());
    on_comboVertCH1_currentIndexChanged(ui->comboVertCH1->currentIndex());
    on_comboVertCH2_currentIndexChanged(ui->comboVertCH2->currentIndex());
}

MainWindow::~MainWindow()
{
    delete ui;
}


void MainWindow::on_pushButtMainState_clicked()
{    
    if(!scopeRunning)
    {
        //asked to run : initialize first

    }

    scopeRunning=ui->widgetScopeView->ToggleRun(!scopeRunning);
    if(scopeRunning)
        ui->pushButtMainState->setText(tr("STOP"));
    else
        ui->pushButtMainState->setText(tr("RUN"));
}

void MainWindow::on_checkBoxCH1State_toggled(bool checked)
{
    ui->widgetScopeView->setCh1Activated(checked);
}

void MainWindow::on_checkBoxCH2State_toggled(bool checked)
{
    ui->widgetScopeView->setCh2Activated(checked);
}

void MainWindow::on_ComboSpeed_currentIndexChanged(int index)
{
    int MLut[]={1,2,5,10,20,50,100,200,500};
    int mantissa,unit;

    if(index>=0 && index<=2)
        unit=UNIT_NS;
    else if(index>=3 && index<=11)
        unit=UNIT_US;
    else if(index>=12 && index<=20)
        unit=UNIT_MS;
    else if(index==21)
        unit=UNIT_S;
    else
        return;

    mantissa=MLut[(index+6)%9];

    ui->widgetScopeView->setSpeed(mantissa,unit);
}

void MainWindow::on_comboVertCH1_currentIndexChanged(int index)
{
    int lut[]={20,100,200,500,1000};
    if(index>=0 && index<=4)
    {
        ui->widgetScopeView->setCh1Range(lut[index]);
    }
}

void MainWindow::on_comboVertCH2_currentIndexChanged(int index)
{
    int lut[]={20,100,200,500,1000};
    if(index>=0 && index<=4)
    {
        ui->widgetScopeView->setCh2Range(lut[index]);
    }
}


void MainWindow::on_checkBoxFastMode_toggled(bool checked)
{
    ui->widgetScopeView->setFastMode(checked);
    if(checked)
    {
        ui->radioButtonTrigCh1->hide();
        ui->radioButtonTrigCh2->hide();
        ui->labelTrigVal->hide();
        ui->horizontalSliderTrigVal->hide();
    }
    else
    {
        ui->radioButtonTrigCh1->show();
        ui->radioButtonTrigCh2->show();
        ui->labelTrigVal->show();
        ui->horizontalSliderTrigVal->show();
    }
}

void MainWindow::on_radioButtonTrigCh1_toggled(bool checked)
{
    if(checked)
    {
        ui->widgetScopeView->setTrigChan(1);
    }
}


void MainWindow::on_radioButtonTrigCh2_toggled(bool checked)
{
    if(checked)
    {
        ui->widgetScopeView->setTrigChan(2);
    }
}

void MainWindow::on_horizontalSliderTrigVal_valueChanged(int value)
{
    ui->widgetScopeView->setTrigValue(((double)value-50.0)/50.0);
}

void MainWindow::on_checkBoxFallingEdge_toggled(bool checked)
{
    ui->widgetScopeView->setEdgeType(checked);
}

void MainWindow::on_checkBoxFilter_toggled(bool checked)
{
    ui->widgetScopeView->setTrigFilter(checked);
}

void MainWindow::on_horizontalSliderOffsetCH1_valueChanged(int value)
{
    ui->widgetScopeView->setCh1Offset((double)value/50.0-1.0);
}

void MainWindow::on_horizontalSliderOffsetCH2_valueChanged(int value)
{
    ui->widgetScopeView->setCh2Offset((double)value/50.0-1.0);
}
