/*
    qtZenOscillo : Software for using DSO-2020 usb scope under Linux
    Copyright (C) 2015 Olivier Poitevin

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

    Contact : code@zener.fr

*/

#include "usbcom.h"

UsbCom::UsbCom()
{
    opened=false;
    dev=NULL;
    udev=NULL;
    usb_init();
}

UsbCom::~UsbCom()
{

    if(opened)
    {
        usb_close(udev);
    }

}

// look for correct device
bool UsbCom::getUsbComDevice(int idVendor,int idProduct)
{
    struct usb_bus *curBus;
    struct usb_device *curDev;

    usb_find_busses();
    usb_find_devices();

    if(!usb_busses)
    {
        return false;
    }

    for(curBus=usb_busses;curBus;curBus=curBus->next)
    {
        for(curDev=curBus->devices;curDev;curDev=curDev->next)
        {
            if(curDev->descriptor.idVendor==idVendor && curDev->descriptor.idProduct==idProduct)
            {
                // found it
                dev=curDev;
                return true;
            }
        }
    }
    // not found
    // set error string here
    return false;
}

bool UsbCom::openDevice()
{
    if(opened)
    {
        return true;
    }
    if(!(udev=usb_open(dev)))
    {
        // set error string here
        return false;
    }
    opened=true;
    return true;
}

bool UsbCom::closeDevice()
{
    if(!opened)
    {
        return true;
    }
    usb_close(udev);
    opened=false;
    return true;
}

bool UsbCom::usbWriteVendor(int request,int value,int index,char *bytes,int size,int timeout)
{
    if(!opened)
    {
        return false;
    }
    int status=usb_control_msg(udev,
            USB_DIR_OUT|USB_TYPE_VENDOR|USB_RECIP_DEVICE,
            request,value,index,bytes,size,timeout);
    if(status!=size)
    {
        // set error string here
        return false;
    }
    return true;
}

int UsbCom::usbBulkRead(int endpoint,char *bytes,int size,int timeout)
{
    int status;

    if(!opened)
    {
        return -1;
    }
    status=usb_bulk_read(udev,endpoint,bytes,size,timeout);
    // set error string here
    return status;
}

